import QtQuick
import QtQuick.Templates as T
import QtQuick.Controls.impl

import Core

/**
 * @brief Виджет тумблера
 */
T.Switch {
    id: control
    Style.type: "Switch"

    implicitWidth: indicator.implicitWidth + spacing + label.implicitWidth - label.leftPadding - label.rightPadding
    implicitHeight: Math.max(indicator.implicitHeight, label.implicitHeight)

    padding: 0
    spacing: 16

    indicator: Rectangle {
        id: indicator
        y: (parent.implicitHeight - height) / 2
        x: control.mirrored ? label.implicitWidth - label.rightPadding + parent.spacing : 0
        implicitWidth: 88
        implicitHeight: 56
        radius: width / 2
        color: control.Style.background.color

        Rectangle {
            x: control.checked ? parent.width - width - 6 : 6
            y: (parent.height - height) / 2
            width: 44
            height: width
            radius: width / 2
            color: control.Style.content.color

            Behavior on x {
                enabled: !Context.context || Context.onTop
                SmoothedAnimation {
                    duration: Style.animationDuration("switch", 100)
                }
            }
        }
        Behavior on color {
            enabled: !Context.context || Context.onTop
            ColorAnimation {
                duration: Style.animationDuration("switch", 100)
            }
        }
    }

    contentItem: CheckLabel {
        id: label
        y: (parent.implicitHeight - height) / 2
        leftPadding: !control.mirrored ? control.indicator.width + control.spacing : 0
        rightPadding: control.mirrored ? control.indicator.width + control.spacing : 0

        text: control.text
        font: control.Style.text.font
        color: control.Style.text.color
    }
}
